@@ -7,8 +7,10 @@ a release version. Release versions are git tagged with the version.
 """
 
 name = "nengo_sphinx_theme"
-version_info = (1, 0, 0)  # (major, minor, patch)
+version_info = (1, 2, 1)  # (major, minor, patch)
 dev = None
 
-version = "{v}{dev}".format(v='.'.join(str(v) for v in version_info),
-                            dev=('.dev%d' % dev) if dev is not None else '')
+version = "{v}{dev}".format(
+    v=".".join(str(v) for v in version_info),
+    dev=(".dev%d" % dev) if dev is not None else "",
+)
